.. module:: cupyx

CuPy-specific Functions
=======================

CuPy-specific functions are placed under ``cupyx`` namespace.

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.rsqrt
   cupyx.scatter_add
   cupyx.scatter_max
   cupyx.scatter_min
